@@ -1,27 +1,29 @@
-require 'puppet/application'
+# frozen_string_literal: true
+
+require_relative '../../puppet/application'
 
 class Puppet::Application::Doc < Puppet::Application
-  run_mode :master
+  run_mode :server
 
   attr_accessor :unknown_args, :manifest
 
   def preinit
-    {:references => [], :mode => :text, :format => :to_markdown }.each do |name,value|
+    { :references => [], :mode => :text, :format => :to_markdown }.each do |name, value|
       options[name] = value
     end
     @unknown_args = []
     @manifest = false
   end
 
-  option("--all","-a")
-  option("--outputdir OUTPUTDIR","-o")
-  option("--verbose","-v")
-  option("--debug","-d")
+  option("--all", "-a")
+  option("--outputdir OUTPUTDIR", "-o")
+  option("--verbose", "-v")
+  option("--debug", "-d")
   option("--charset CHARSET")
 
   option("--format FORMAT", "-f") do |arg|
     method = "to_#{arg}"
-    require 'puppet/util/reference'
+    require_relative '../../puppet/util/reference'
     if Puppet::Util::Reference.method_defined?(method)
       options[:format] = method
     else
@@ -30,16 +32,16 @@ class Puppet::Application::Doc < Puppet::Application
   end
 
   option("--mode MODE", "-m") do |arg|
-    require 'puppet/util/reference'
-    if Puppet::Util::Reference.modes.include?(arg) or arg.intern==:rdoc
+    require_relative '../../puppet/util/reference'
+    if Puppet::Util::Reference.modes.include?(arg) or arg.intern == :rdoc
       options[:mode] = arg.intern
     else
       raise _("Invalid output mode %{arg}") % { arg: arg }
     end
   end
 
-  option("--list", "-l") do |arg|
-    require 'puppet/util/reference'
+  option("--list", "-l") do |_arg|
+    require_relative '../../puppet/util/reference'
     refs = Puppet::Util::Reference.references(Puppet.lookup(:current_environment))
     puts refs.collect { |r| Puppet::Util::Reference.reference(r).doc }.join("\n")
     exit(0)
@@ -54,73 +56,73 @@ class Puppet::Application::Doc < Puppet::Application
   end
 
   def help
-    <<-HELP
+    <<~HELP
 
-puppet-doc(8) -- #{summary}
-========
+      puppet-doc(8) -- #{summary}
+      ========
 
-SYNOPSIS
---------
-Generates a reference for all Puppet types. Largely meant for internal
-Puppet Inc. use. (Deprecated)
+      SYNOPSIS
+      --------
+      Generates a reference for all Puppet types. Largely meant for internal
+      Puppet Inc. use. (Deprecated)
 
 
-USAGE
------
-puppet doc [-h|--help] [-l|--list]
-  [-r|--reference <reference-name>]
+      USAGE
+      -----
+      puppet doc [-h|--help] [-l|--list]
+        [-r|--reference <reference-name>]
 
 
-DESCRIPTION
------------
-This deprecated command generates a Markdown document to stdout
-describing all installed Puppet types or all allowable arguments to
-puppet executables. It is largely meant for internal use and is used to
-generate the reference document available on the Puppet Inc. web site.
+      DESCRIPTION
+      -----------
+      This deprecated command generates a Markdown document to stdout
+      describing all installed Puppet types or all allowable arguments to
+      puppet executables. It is largely meant for internal use and is used to
+      generate the reference document available on the Puppet Inc. web site.
 
-For Puppet module documentation (and all other use cases) this command
-has been superseded by the "puppet-strings"
-module - see https://github.com/puppetlabs/puppetlabs-strings for more information.
+      For Puppet module documentation (and all other use cases) this command
+      has been superseded by the "puppet-strings"
+      module - see https://github.com/puppetlabs/puppetlabs-strings for more information.
 
-This command (puppet-doc) will be removed once the
-puppetlabs internal documentation processing pipeline is completely based
-on puppet-strings.
+      This command (puppet-doc) will be removed once the
+      puppetlabs internal documentation processing pipeline is completely based
+      on puppet-strings.
 
-OPTIONS
--------
+      OPTIONS
+      -------
 
-* --help:
-  Print this help message
+      * --help:
+        Print this help message
 
-* --reference:
-  Build a particular reference. Get a list of references by running
-  'puppet doc --list'.
+      * --reference:
+        Build a particular reference. Get a list of references by running
+        'puppet doc --list'.
 
 
-EXAMPLE
--------
-    $ puppet doc -r type > /tmp/type_reference.markdown
+      EXAMPLE
+      -------
+          $ puppet doc -r type > /tmp/type_reference.markdown
 
 
-AUTHOR
-------
-Luke Kanies
+      AUTHOR
+      ------
+      Luke Kanies
 
 
-COPYRIGHT
----------
-Copyright (c) 2011 Puppet Inc., LLC Licensed under the Apache 2.0 License
+      COPYRIGHT
+      ---------
+      Copyright (c) 2011 Puppet Inc., LLC Licensed under the Apache 2.0 License
 
-HELP
+    HELP
   end
 
-  def handle_unknown( opt, arg )
-    @unknown_args << {:opt => opt, :arg => arg }
+  def handle_unknown(opt, arg)
+    @unknown_args << { :opt => opt, :arg => arg }
     true
   end
 
   def run_command
-    return [:rdoc].include?(options[:mode]) ? send(options[:mode]) : other
+    [:rdoc].include?(options[:mode]) ? send(options[:mode]) : other
   end
 
   def rdoc
@@ -136,7 +138,7 @@ HELP
 
     Puppet.settings[:document_all] = options[:all] || false
     begin
-      require 'puppet/util/rdoc'
+      require_relative '../../puppet/util/rdoc'
       if @manifest
         Puppet::Util::RDoc.manifestdoc(files)
       else
@@ -151,11 +153,11 @@ HELP
   end
 
   def other
-    text = ""
+    text = ''.dup
     with_contents = options[:references].length <= 1
     exit_code = 0
-    require 'puppet/util/reference'
-    options[:references].sort { |a,b| a.to_s <=> b.to_s }.each do |name|
+    require_relative '../../puppet/util/reference'
+    options[:references].sort_by(&:to_s).each do |name|
       section = Puppet::Util::Reference.reference(name)
       raise _("Could not find reference %{name}") % { name: name } unless section
 
@@ -171,11 +173,7 @@ HELP
 
     text += Puppet::Util::Reference.footer unless with_contents # We've only got one reference
 
-    if options[:mode] == :pdf
-      Puppet::Util::Reference.pdf(text)
-    else
-      puts text
-    end
+    puts text
 
     exit exit_code
   end
@@ -199,7 +197,7 @@ HELP
   def setup_reference
     if options[:all]
       # Don't add dynamic references to the "all" list.
-      require 'puppet/util/reference'
+      require_relative '../../puppet/util/reference'
       refs = Puppet::Util::Reference.references(Puppet.lookup(:current_environment))
       options[:references] = refs.reject do |ref|
         Puppet::Util::Reference.reference(ref).dynamic?
@@ -215,7 +213,7 @@ HELP
     if @unknown_args.size > 0
       @unknown_args.each do |option|
         # force absolute path for modulepath when passed on commandline
-        if option[:opt]=="--modulepath"
+        if option[:opt] == "--modulepath"
           option[:arg] = option[:arg].split(::File::PATH_SEPARATOR).collect { |p| ::File.expand_path(p) }.join(::File::PATH_SEPARATOR)
         end
         Puppet.settings.handlearg(option[:opt], option[:arg])
